#ifndef NT2_INCLUDE_FUNCTIONS_C_REAL_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_C_REAL_HPP_INCLUDED

#include <nt2/complex/include/functions/c_real.hpp>

#endif
